==> kdebase-3.4.2.tar.bz2: kdebase-3.4.2/kcontrol/kfontinst/kcmfontinst/KFileFontIconView.h <==
#ifndef __KFILE_FONT_ICON_VIEW_H__
#define __KFILE_FONT_ICON_VIEW_H__

////////////////////////////////////////////////////////////////////////////////
//
// Class Name    : KFI::CKFileFontIconView
// Author        : Craig Drummond
// Project       : K Font Installer
// Creation Date : 01/08/2003
// Version       : $Revision: 363303 $ $Date: 2004-11-16 03:08:35 +0100 (Di, 16 Nov 2004) $
//
////////////////////////////////////////////////////////////////////////////////
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////////
// (C) Craig Drummond, 2003, 2004
////////////////////////////////////////////////////////////////////////////////

#include <kfileiconview.h>

namespace KFI
{

class CKFileFontIconView : public KFileIconView
{
    public:

    CKFileFontIconView(QWidget *parent, const char *name) : KFileIconView(parent, name) {}
    virtual ~CKFileFontIconView()                                                       {}

    protected:

    // DND support
    void contentsDragEnterEvent(QDragEnterEvent *e);
    void contentsDragMoveEvent(QDragMoveEvent *e);
    void contentsDropEvent(QDropEvent *e);
    bool acceptDrag(QDropEvent *e) const;
};

}

#endif

==> kdebase-3.5.0.tar.bz2: kdebase-3.5.0/kcontrol/kfontinst/kcmfontinst/KFileFontIconView.h <==
#ifndef __KFILE_FONT_ICON_VIEW_H__
#define __KFILE_FONT_ICON_VIEW_H__

////////////////////////////////////////////////////////////////////////////////
//
// Class Name    : KFI::CKFileFontIconView
// Author        : Craig Drummond
// Project       : K Font Installer
// Creation Date : 01/08/2003
// Version       : $Revision: 465343 $ $Date: 2005-09-29 15:24:25 +0200 (Do, 29 Sep 2005) $
//
////////////////////////////////////////////////////////////////////////////////
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//
////////////////////////////////////////////////////////////////////////////////
// (C) Craig Drummond, 2003, 2004
////////////////////////////////////////////////////////////////////////////////

#include <kfileiconview.h>

namespace KFI
{

class CKFileFontIconView : public KFileIconView
{
    public:

    CKFileFontIconView(QWidget *parent, const char *name) : KFileIconView(parent, name) {}
    virtual ~CKFileFontIconView()                                                       {}

    protected:

    // DND support
    void contentsDragEnterEvent(QDragEnterEvent *e);
    void contentsDragMoveEvent(QDragMoveEvent *e);
    void contentsDropEvent(QDropEvent *e);
    bool acceptDrag(QDropEvent *e) const;
};

}

#endif
